@@ -1,10 +1,7 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "battlefield.h"
@@ -304,7 +301,7 @@ void BattleField::clear()
             deleted_ships.insert(ship);
         }
         m_board[p].setType(Element::WATER);
-        m_board[p].setParent(0);
+        m_board[p].setParent(nullptr);
     }
     m_ships=0;
 }
